==> spread-5.3.0.5-py3-none-any.whl: spread_dashboard/asgi.py <==
"""
ASGI config for dashboard project.

It exposes the ASGI callable as a module-level variable named ``application``.

For more information on this file, see
https://docs.djangoproject.com/en/3.0/howto/deployment/asgi/
"""
import logging.config
import os
import sys

from django.core.asgi import get_asgi_application

django_asgi_app = get_asgi_application()

from channels.auth import AuthMiddlewareStack
from channels.routing import ProtocolTypeRouter, URLRouter

import spread_dashboard.monitor.routing


DEFAULT_LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'default': {'format': u'%(levelname)-8s [%(asctime)s]  %(message)s'},
    },
    'handlers': {
        'console': {
            'level': 'DEBUG',
            'formatter': 'default',
            'class': 'logging.StreamHandler',
            'stream': sys.stdout
        },
    },
    'root': {
        'handlers': ['console'],
        'level': 'DEBUG',
    },
    'loggers': {
        'daphne.ws_protocol': {'level': logging.INFO},
        'asyncio': {'level': logging.INFO},
        'daphne.http_protocol': {'level': logging.INFO},
        'can.interfaces.socketcan.socketcan': {'level': logging.WARNING},
    }
}

logging.basicConfig(format=u'%(levelname)-8s [%(asctime)s]  %(message)s', level=logging.DEBUG, stream=sys.stdout)
logging.config.dictConfig(DEFAULT_LOGGING)

if os.environ.get('DJANGO_SETTINGS_MODULE') == 'spread_dashboard.settings':
    logging.info('run migrate spread_dashboard')
    os.system('sudo spread_utils_dashboard migrate')
    logging.info('migrate OK')

application = ProtocolTypeRouter({
    "http": django_asgi_app,
    "websocket": AuthMiddlewareStack(
        URLRouter(
            spread_dashboard.monitor.routing.websocket_urlpatterns
        )
    ),
})

==> spread-5.9.0.59-py3-none-any.whl: spread_dashboard/asgi.py <==
"""
ASGI config for dashboard project.

It exposes the ASGI callable as a module-level variable named ``application``.

For more information on this file, see
https://docs.djangoproject.com/en/3.0/howto/deployment/asgi/
"""
import logging.config
import os
import sys

from django.core.asgi import get_asgi_application

django_asgi_app = get_asgi_application()

from channels.auth import AuthMiddlewareStack
from channels.routing import ProtocolTypeRouter, URLRouter

import spread_dashboard.routing


DEFAULT_LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'default': {'format': u'%(levelname)-8s [%(asctime)s]  %(message)s'},
    },
    'handlers': {
        'console': {
            'level': 'DEBUG',
            'formatter': 'default',
            'class': 'logging.StreamHandler',
            'stream': sys.stdout
        },
    },
    'root': {
        'handlers': ['console'],
        'level': 'DEBUG',
    },
    'loggers': {
        'daphne.ws_protocol': {'level': logging.INFO},
        'asyncio': {'level': logging.INFO},
        'daphne.http_protocol': {'level': logging.INFO},
        'can.interfaces.socketcan.socketcan': {'level': logging.WARNING},
    }
}

logging.basicConfig(format=u'%(levelname)-8s [%(asctime)s]  %(message)s', level=logging.DEBUG, stream=sys.stdout)
logging.config.dictConfig(DEFAULT_LOGGING)

if os.environ.get('DJANGO_SETTINGS_MODULE') == 'spread_dashboard.settings':
    logging.info('run migrate spread_dashboard')
    os.system('sudo spread_utils_dashboard migrate')
    logging.info('migrate OK')

application = ProtocolTypeRouter({
    "http": django_asgi_app,
    "websocket": AuthMiddlewareStack(
        URLRouter(
            spread_dashboard.routing.websocket_urlpatterns
        )
    ),
})
